@@ -542,7 +542,7 @@ void KDirListerTest::testRenameItem()
     const QString dirPath = m_tempDir.path() + '/';
     connect(&m_dirLister, &KCoreDirLister::refreshItems, this, &KDirListerTest::slotRefreshItems2);
     const QString path = dirPath + "toplevelfile_2";
-    const QString newPath = dirPath + "toplevelfile_2.renamed.html";
+    const QString newPath = dirPath + "toplevelfile_2.renamed.cpp";
 
     KIO::SimpleJob *job = KIO::rename(QUrl::fromLocalFile(path), QUrl::fromLocalFile(newPath), KIO::HideProgressInfo);
     QVERIFY(job->exec());
@@ -554,7 +554,7 @@ void KDirListerTest::testRenameItem()
     QCOMPARE(entry.first.url().toLocalFile(), path);
     QCOMPARE(entry.first.mimetype(), QString("application/octet-stream"));
     QCOMPARE(entry.second.url().toLocalFile(), newPath);
-    QCOMPARE(entry.second.mimetype(), QString("text/html"));
+    QCOMPARE(entry.second.mimetype(), QString("text/x-c++src"));
     disconnect(&m_dirLister, nullptr, this, nullptr);
 
     // Let's see what KDirLister has in cache now
@@ -584,7 +584,7 @@ void KDirListerTest::testRenameAndOverwrite() // has to be run after testRenameI
 
     m_refreshedItems.clear();
     connect(&m_dirLister, &KCoreDirLister::refreshItems, this, &KDirListerTest::slotRefreshItems);
-    const QString newPath = dirPath + "toplevelfile_2.renamed.html";
+    const QString newPath = dirPath + "toplevelfile_2.renamed.cpp";
 
     KIO::SimpleJob *job = KIO::rename(QUrl::fromLocalFile(newPath), QUrl::fromLocalFile(path), KIO::Overwrite | KIO::HideProgressInfo);
     bool ok = job->exec();
@@ -1144,7 +1144,7 @@ void KDirListerTest::testWatchingAfterCopyJob() // #331582
 
     // Create a new file and verify that the dir lister notices it.
     m_items.clear();
-    createTestFile(path + "a");
+    createTestFile(path + QLatin1Char('a'));
     QVERIFY(spyCompleted.wait(1000));
     QTRY_VERIFY(m_dirLister.isFinished());
     QTRY_COMPARE(m_items.count(), 1);
@@ -1160,7 +1160,7 @@ void KDirListerTest::testWatchingAfterCopyJob() // #331582
     // Now try to create a second new file and verify that the
     // dir lister notices it.
     m_items.clear();
-    createTestFile(path + "b");
+    createTestFile(path + QLatin1Char('b'));
 
     // This should end up in "KCoreDirListerCache::slotFileDirty"
     QTRY_COMPARE(m_items.count(), 1);
@@ -1327,7 +1327,7 @@ void KDirListerTest::testRenameDirectory() // #401552
     m_dirLister.openUrl(QUrl::fromLocalFile(dirW), KDirLister::NoFlags);
 
     // Try to reproduce the bug #401552 renaming the w directory several times if needed
-    const QStringList dirs = { dirW + "___", dirW + "_", dirW + "______",  dirW + "_c",
+    const QStringList dirs = { dirW + "___", dirW + QLatin1Char('_'), dirW + "______",  dirW + "_c",
         dirW + "___", dirW + "_________" };
 
     QString currDir = dirW;
@@ -1397,8 +1397,8 @@ void KDirListerTest::waitUntilMTimeChange(const QString &path)
 
     QFileInfo fi(path);
     QVERIFY(fi.exists());
-    const QDateTime ctime = qMax(fi.lastModified(), fi.created());
-    waitUntilAfter(ctime);
+    const QDateTime mtime = fi.lastModified();
+    waitUntilAfter(mtime);
 }
 
 void KDirListerTest::waitUntilAfter(const QDateTime &ctime)
@@ -1407,7 +1407,7 @@ void KDirListerTest::waitUntilAfter(const QDateTime &ctime)
     QDateTime now;
     Q_FOREVER {
         now = QDateTime::currentDateTime();
-        if (now.toTime_t() == ctime.toTime_t()) { // truncate milliseconds
+        if (now.toSecsSinceEpoch() == ctime.toSecsSinceEpoch()) { // truncate milliseconds
             totalWait += 50;
             QTest::qWait(50);
         } else {
