@@ -19,8 +19,10 @@
 
 // This file can only be included once in a given binary
 
+#include <QTest>
+#include <QDateTime>
 #include <QDebug>
-#include <QtCore/qglobal.h>
+#include <qglobal.h>
 #include <qstandardpaths.h>
 #include <qplatformdefs.h>
 #include <QDir>
@@ -35,7 +37,7 @@
 
 QString homeTmpDir()
 {
-    const QString dir(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + "/kiotests/");
+    const QString dir(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QStringLiteral("/kiotests/"));
     if (!QFile::exists(dir)) {
         const bool ok = QDir().mkpath(dir);
         if (!ok) {
@@ -45,20 +47,20 @@ QString homeTmpDir()
     return dir;
 }
 
-QDateTime s_referenceTimeStamp;
+static QDateTime s_referenceTimeStamp;
 
 static void setTimeStamp(const QString &path, const QDateTime &mtime)
 {
 #ifdef Q_OS_UNIX
     // Put timestamp in the past so that we can check that the listing is correct
     struct utimbuf utbuf;
-    utbuf.actime = mtime.toTime_t();
+    utbuf.actime = mtime.toSecsSinceEpoch();
     utbuf.modtime = utbuf.actime;
     utime(QFile::encodeName(path), &utbuf);
     //qDebug( "Time changed for %s", qPrintable( path ) );
 #elif defined(Q_OS_WIN)
     struct _utimbuf utbuf;
-    utbuf.actime = mtime.toTime_t();
+    utbuf.actime = mtime.toSecsSinceEpoch();
     utbuf.modtime = utbuf.actime;
     _wutime(reinterpret_cast<const wchar_t *>(path.utf16()), &utbuf);
 #endif
@@ -66,6 +68,7 @@ static void setTimeStamp(const QString &path, const QDateTime &mtime)
 
 static void createTestFile(const QString &path, bool plainText = false)
 {
+    QDir().mkpath(QFileInfo(path).absolutePath());
     QFile f(path);
     if (!f.open(QIODevice::WriteOnly)) {
         qFatal("Couldn't create %s", qPrintable(path));
@@ -80,7 +83,7 @@ static void createTestFile(const QString &path, bool plainText = false)
 static void createTestSymlink(const QString &path, const QByteArray &target = "/IDontExist")
 {
     QFile::remove(path);
-    bool ok = KIOPrivate::createSymlink(target, path);     // broken symlink
+    bool ok = KIOPrivate::createSymlink(QString::fromLatin1(target), path);     // broken symlink
     if (!ok) {
         qFatal("couldn't create symlink: %s", strerror(errno));
     }
@@ -99,14 +102,14 @@ static inline void createTestDirectory(const QString &path, CreateTestDirectoryO
     if (!ok && !dir.exists()) {
         qFatal("Couldn't create %s", qPrintable(path));
     }
-    createTestFile(path + "/testfile");
+    createTestFile(path + QStringLiteral("/testfile"));
     if ((opt & NoSymlink) == 0) {
 #ifndef Q_OS_WIN
-        createTestSymlink(path + "/testlink");
-        QVERIFY(QFileInfo(path + "/testlink").isSymLink());
+        createTestSymlink(path + QStringLiteral("/testlink"));
+        QVERIFY(QFileInfo(path + QStringLiteral("/testlink")).isSymLink());
 #else
         // to not change the filecount everywhere in the tests
-        createTestFile(path + "/testlink");
+        createTestFile(path + QStringLiteral("/testlink"));
 #endif
     }
     setTimeStamp(path, s_referenceTimeStamp);
@@ -122,8 +125,8 @@ public:
           m_askSkipCalled(0),
           m_askDeleteCalled(0),
           m_messageBoxCalled(0),
-          m_renameResult(KIO::R_SKIP),
-          m_skipResult(KIO::S_SKIP),
+          m_renameResult(KIO::Result_Skip),
+          m_skipResult(KIO::Result_Skip),
           m_deleteResult(false),
           m_messageBoxResult(0)
     {
@@ -140,20 +143,20 @@ public:
                                            const QDateTime  & = QDateTime(),
                                            const QDateTime  & = QDateTime(),
                                            const QDateTime  & = QDateTime(),
-                                           const QDateTime  & = QDateTime()) Q_DECL_OVERRIDE {
+                                           const QDateTime  & = QDateTime()) override {
         Q_UNUSED(job)
         Q_UNUSED(caption)
         Q_UNUSED(src)
         Q_UNUSED(dest)
         Q_UNUSED(options)
-        Q_UNUSED(newDest)
+        newDest = m_renamedest;
         ++m_askFileRenameCalled;
         return m_renameResult;
     }
 
     KIO::SkipDialog_Result askSkip(KJob *job,
                                    KIO::SkipDialog_Options options,
-                                   const QString &error_text) Q_DECL_OVERRIDE {
+                                   const QString &error_text) override {
         Q_UNUSED(job)
         Q_UNUSED(options)
         Q_UNUSED(error_text)
@@ -162,7 +165,7 @@ public:
     }
 
     bool askDeleteConfirmation(const QList<QUrl> &urls, DeletionType deletionType,
-                               ConfirmationType confirmationType) Q_DECL_OVERRIDE {
+                               ConfirmationType confirmationType) override {
         Q_UNUSED(urls);
         Q_UNUSED(deletionType);
         Q_UNUSED(confirmationType);
@@ -177,8 +180,7 @@ public:
                           const QString &iconYes = QString(),
                           const QString &iconNo = QString(),
                           const QString &dontAskAgainName = QString(),
-                          const KIO::MetaData &sslMetaData = KIO::MetaData()) Q_DECL_OVERRIDE
-    {
+                          const KIO::MetaData &metaData = KIO::MetaData()) override {
         Q_UNUSED(type);
         Q_UNUSED(text);
         Q_UNUSED(caption);
@@ -187,7 +189,7 @@ public:
         Q_UNUSED(iconYes);
         Q_UNUSED(iconNo);
         Q_UNUSED(dontAskAgainName);
-        Q_UNUSED(sslMetaData);
+        Q_UNUSED(metaData);
         ++m_messageBoxCalled;
         return m_messageBoxResult;
     }
@@ -202,4 +204,5 @@ public:
     KIO::SkipDialog_Result m_skipResult;
     bool m_deleteResult;
     int m_messageBoxResult;
+    QString m_renamedest;
 };
