@@ -67,10 +67,6 @@
 #include <QStandardPaths>
 #include <QDataStream>
 
-#if HAVE_STATX
-#include <sys/stat.h>
-#endif
-
 #if HAVE_VOLMGT
 #include <volmgt.h>
 #include <sys/mnttab.h>
@@ -93,10 +89,6 @@ using namespace KIO;
 #define MAX_IPC_SIZE (1024*32)
 
 static QString readLogFile(const QByteArray &_filename);
-#if HAVE_POSIX_ACL
-static void appendACLAtoms(const QByteArray &path, UDSEntry &entry,
-                           mode_t type);
-#endif
 
 extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
 {
@@ -170,64 +162,6 @@ FileProtocol::~FileProtocol()
 {
 }
 
-#if HAVE_POSIX_ACL
-static QString aclToText(acl_t acl)
-{
-    ssize_t size = 0;
-    char *txt = acl_to_text(acl, &size);
-    const QString ret = QString::fromLatin1(txt, size);
-    acl_free(txt);
-    return ret;
-}
-#endif
-
-int FileProtocol::setACL(const char *path, mode_t perm, bool directoryDefault)
-{
-    int ret = 0;
-#if HAVE_POSIX_ACL
-
-    const QString ACLString = metaData(QStringLiteral("ACL_STRING"));
-    const QString defaultACLString = metaData(QStringLiteral("DEFAULT_ACL_STRING"));
-    // Empty strings mean leave as is
-    if (!ACLString.isEmpty()) {
-        acl_t acl = nullptr;
-        if (ACLString == QLatin1String("ACL_DELETE")) {
-            // user told us to delete the extended ACL, so let's write only
-            // the minimal (UNIX permission bits) part
-            acl = acl_from_mode(perm);
-        }
-        acl = acl_from_text(ACLString.toLatin1().constData());
-        if (acl_valid(acl) == 0) {     // let's be safe
-            ret = acl_set_file(path, ACL_TYPE_ACCESS, acl);
-            // qDebug() << "Set ACL on:" << path << "to:" << aclToText(acl);
-        }
-        acl_free(acl);
-        if (ret != 0) {
-            return ret;    // better stop trying right away
-        }
-    }
-
-    if (directoryDefault && !defaultACLString.isEmpty()) {
-        if (defaultACLString == QLatin1String("ACL_DELETE")) {
-            // user told us to delete the default ACL, do so
-            ret += acl_delete_def_file(path);
-        } else {
-            acl_t acl = acl_from_text(defaultACLString.toLatin1().constData());
-            if (acl_valid(acl) == 0) {     // let's be safe
-                ret += acl_set_file(path, ACL_TYPE_DEFAULT, acl);
-                // qDebug() << "Set Default ACL on:" << path << "to:" << aclToText(acl);
-            }
-            acl_free(acl);
-        }
-    }
-#else
-    Q_UNUSED(path);
-    Q_UNUSED(perm);
-    Q_UNUSED(directoryDefault);
-#endif
-    return ret;
-}
-
 void FileProtocol::chmod(const QUrl &url, int permissions)
 {
     const QString path(url.toLocalFile());
@@ -829,241 +763,6 @@ void FileProtocol::put(const QUrl &url, int _mode, KIO::JobFlags _flags)
     finished();
 }
 
-QString FileProtocol::getUserName(KUserId uid) const
-{
-    if (Q_UNLIKELY(!uid.isValid())) {
-        return QString();
-    }
-    auto it = mUsercache.find(uid);
-    if (it == mUsercache.end()) {
-        KUser user(uid);
-        QString name = user.loginName();
-        if (name.isEmpty()) {
-            name = uid.toString();
-        }
-        it = mUsercache.insert(uid, name);
-    }
-    return *it;
-}
-
-QString FileProtocol::getGroupName(KGroupId gid) const
-{
-    if (Q_UNLIKELY(!gid.isValid())) {
-        return QString();
-    }
-    auto it = mGroupcache.find(gid);
-    if (it == mGroupcache.end()) {
-        KUserGroup group(gid);
-        QString name = group.name();
-        if (name.isEmpty()) {
-            name = gid.toString();
-        }
-        it = mGroupcache.insert(gid, name);
-    }
-    return *it;
-}
-
-#if HAVE_STATX
-// statx syscall is available
-inline int LSTAT(const char* path, struct statx * buff) {
-    return statx(AT_FDCWD, path, AT_SYMLINK_NOFOLLOW, STATX_BASIC_STATS | STATX_BTIME, buff);
-}
-inline int STAT(const char* path, struct statx * buff) {
-    return statx(AT_FDCWD, path, AT_STATX_SYNC_AS_STAT, STATX_BASIC_STATS | STATX_BTIME, buff);
-}
-inline static uint16_t stat_mode(struct statx &buf) { return buf.stx_mode; }
-inline static uint32_t stat_dev(struct statx &buf) { return buf.stx_dev_major; }
-inline static uint64_t stat_ino(struct statx &buf) { return buf.stx_ino; }
-inline static uint64_t stat_size(struct statx &buf) { return buf.stx_size; }
-inline static uint32_t stat_uid(struct statx &buf) { return buf.stx_uid; }
-inline static uint32_t stat_gid(struct statx &buf) { return buf.stx_gid; }
-inline static int64_t stat_atime(struct statx &buf) { return buf.stx_atime.tv_sec; }
-inline static int64_t stat_mtime(struct statx &buf) { return buf.stx_mtime.tv_sec; }
-#else
-// regular stat struct
-inline int LSTAT(const char* path, QT_STATBUF * buff) {
-    return QT_LSTAT(path, buff);
-}
-inline int STAT(const char* path, QT_STATBUF * buff) {
-    return QT_STAT(path, buff);
-}
-inline static mode_t stat_mode(QT_STATBUF &buf) { return buf.st_mode; }
-inline static dev_t stat_dev(QT_STATBUF &buf) { return buf.st_dev; }
-inline static ino_t stat_ino(QT_STATBUF &buf) { return buf.st_ino; }
-inline static off_t stat_size(QT_STATBUF &buf) { return buf.st_size; }
-#ifndef Q_OS_WIN
-inline static uid_t stat_uid(QT_STATBUF &buf) { return buf.st_uid; }
-inline static gid_t stat_gid(QT_STATBUF &buf) { return buf.st_gid; }
-#endif
-inline static time_t stat_atime(QT_STATBUF &buf) { return buf.st_atime; }
-inline static time_t stat_mtime(QT_STATBUF &buf) { return buf.st_mtime; }
-#endif
-
-bool FileProtocol::createUDSEntry(const QString &filename, const QByteArray &path, UDSEntry &entry,
-                                  short int details)
-{
-    assert(entry.count() == 0); // by contract :-)
-    switch (details) {
-    case 0:
-        // filename, access, type, size, linkdest
-        entry.reserve(5);
-        break;
-    case 1:
-        // uid, gid, atime, mtime, btime
-        entry.reserve(10);
-        break;
-    case 2:
-        // acl data
-        entry.reserve(13);
-        break;
-    default: // case details > 2
-        // dev, inode
-        entry.reserve(15);
-        break;
-    }
-    entry.fastInsert(KIO::UDSEntry::UDS_NAME, filename);
-
-    mode_t type;
-    mode_t access;
-    bool isBrokenSymLink = false;
-    signed long long size = 0LL;
-#if HAVE_POSIX_ACL
-    QByteArray targetPath = path;
-#endif
-
-#if HAVE_STATX
-    // statx syscall is available
-    struct statx buff;
-#else
-    QT_STATBUF buff;
-#endif
-
-    if (LSTAT(path.data(), &buff) == 0)  {
-
-        if (details > 2) {
-            entry.fastInsert(KIO::UDSEntry::UDS_DEVICE_ID, stat_dev(buff));
-            entry.fastInsert(KIO::UDSEntry::UDS_INODE, stat_ino(buff));
-        }
-
-        if ((stat_mode(buff) & QT_STAT_MASK) == QT_STAT_LNK) {
-
-#ifdef Q_OS_WIN
-            const QString linkTarget = QFile::symLinkTarget(QFile::decodeName(path));
-#else
-            // Use readlink on Unix because symLinkTarget turns relative targets into absolute (#352927)
-            #if HAVE_STATX
-                size_t lowerBound = 256;
-                size_t higherBound = 1024;
-                uint64_t s = stat_size(buff);
-                if (s > SIZE_MAX) {
-                    qCWarning(KIO_FILE) << "file size bigger than SIZE_MAX, too big for readlink use!" << path;
-                    return false;
-                }
-                size_t size = static_cast<size_t>(s);
-                using SizeType = size_t;
-            #else
-                off_t lowerBound = 256;
-                off_t higherBound = 1024;
-                off_t size = stat_size(buff);
-                using SizeType = off_t;
-            #endif
-            SizeType bufferSize = qBound(lowerBound, size +1, higherBound);
-            QByteArray linkTargetBuffer;
-            linkTargetBuffer.resize(bufferSize);
-            while (true) {
-                ssize_t n = readlink(path.constData(), linkTargetBuffer.data(), bufferSize);
-                if (n < 0 && errno != ERANGE) {
-                    qCWarning(KIO_FILE) << "readlink failed!" << path;
-                    return false;
-                } else if (n > 0 && static_cast<SizeType>(n) != bufferSize) {
-                    // the buffer was not filled in the last iteration
-                    // we are finished reading, break the loop
-                    linkTargetBuffer.truncate(n);
-                    break;
-                }
-                bufferSize *= 2;
-                linkTargetBuffer.resize(bufferSize);
-            }
-            const QString linkTarget = QFile::decodeName(linkTargetBuffer);
-#endif
-            entry.fastInsert(KIO::UDSEntry::UDS_LINK_DEST, linkTarget);
-
-            // A symlink -> follow it only if details>1
-            if (details > 1) {
-                if (STAT(path.constData(), &buff) == -1) {
-                    isBrokenSymLink = true;
-                } else {
-#if HAVE_POSIX_ACL
-                    // valid symlink, will get the ACLs of the destination
-                    targetPath = linkTargetBuffer;
-#endif
-                }
-            }
-        }
-    } else {
-        // qCWarning(KIO_FILE) << "lstat didn't work on " << path.data();
-        return false;
-    }
-
-    if (isBrokenSymLink) {
-        // It is a link pointing to nowhere
-        type = S_IFMT - 1;
-        access = S_IRWXU | S_IRWXG | S_IRWXO;
-        size = 0LL;
-    } else {
-        type = stat_mode(buff) & S_IFMT; // extract file type
-        access = stat_mode(buff) & 07777; // extract permissions
-        size = stat_size(buff);
-    }
-
-    entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, type);
-    entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, access);
-    entry.fastInsert(KIO::UDSEntry::UDS_SIZE, size);
-
-#if HAVE_POSIX_ACL
-    if (details > 1) {
-        /* Append an atom indicating whether the file has extended acl information
-         * and if withACL is specified also one with the acl itself. If it's a directory
-         * and it has a default ACL, also append that. */
-        appendACLAtoms(targetPath, entry, type);
-    }
-#endif
-
-    if (details > 0) {
-        entry.fastInsert(KIO::UDSEntry::UDS_MODIFICATION_TIME, stat_mtime(buff));
-        entry.fastInsert(KIO::UDSEntry::UDS_ACCESS_TIME, stat_atime(buff));
-#ifndef Q_OS_WIN
-        entry.fastInsert(KIO::UDSEntry::UDS_USER, getUserName(KUserId(stat_uid(buff))));
-        entry.fastInsert(KIO::UDSEntry::UDS_GROUP, getGroupName(KGroupId(stat_gid(buff))));
-#else
-#pragma message("TODO: st_uid and st_gid are always zero, use GetSecurityInfo to find the owner")
-#endif
-
-#ifdef st_birthtime
-        /* For example FreeBSD's and NetBSD's stat contains a field for
-         * the inode birth time: st_birthtime
-         * This however only works on UFS and ZFS, and not, on say, NFS.
-         * Instead of setting a bogus fallback like st_mtime, only use
-         * it if it is greater than 0. */
-        if (buff.st_birthtime > 0) {
-            entry.fastInsert(KIO::UDSEntry::UDS_CREATION_TIME, buff.st_birthtime);
-        }
-#elif defined __st_birthtime
-        /* As above, but OpenBSD calls it slightly differently. */
-        if (buff.__st_birthtime > 0) {
-            entry.fastInsert(KIO::UDSEntry::UDS_CREATION_TIME, buff.__st_birthtime);
-        }
-#elif HAVE_STATX
-        /* And linux version using statx syscall */
-        if (buff.stx_mask & STATX_BTIME) {
-            entry.fastInsert(KIO::UDSEntry::UDS_CREATION_TIME, buff.stx_btime.tv_sec);
-        }
-#endif
-    }
-
-    return true;
-}
-
 void FileProtocol::special(const QByteArray &data)
 {
     int tmp;
@@ -1439,62 +1138,6 @@ static QString readLogFile(const QByteArray &_filename)
     return result;
 }
 
-/*************************************
- *
- * ACL handling helpers
- *
- *************************************/
-#if HAVE_POSIX_ACL
-
-bool FileProtocol::isExtendedACL(acl_t acl)
-{
-    return (acl_equiv_mode(acl, nullptr) != 0);
-}
-
-static void appendACLAtoms(const QByteArray &path, UDSEntry &entry, mode_t type)
-{
-    // first check for a noop
-    if (acl_extended_file(path.data()) == 0) {
-        return;
-    }
-
-    acl_t acl = nullptr;
-    acl_t defaultAcl = nullptr;
-    bool isDir = (type & QT_STAT_MASK) == QT_STAT_DIR;
-    // do we have an acl for the file, and/or a default acl for the dir, if it is one?
-    acl = acl_get_file(path.data(), ACL_TYPE_ACCESS);
-    /* Sadly libacl does not provided a means of checking for extended ACL and default
-     * ACL separately. Since a directory can have both, we need to check again. */
-    if (isDir) {
-        if (acl) {
-            if (!FileProtocol::isExtendedACL(acl)) {
-                acl_free(acl);
-                acl = nullptr;
-            }
-        }
-        defaultAcl = acl_get_file(path.data(), ACL_TYPE_DEFAULT);
-    }
-    if (acl || defaultAcl) {
-        // qDebug() << path.constData() << "has extended ACL entries";
-        entry.fastInsert(KIO::UDSEntry::UDS_EXTENDED_ACL, 1);
-
-        if (acl) {
-            const QString str = aclToText(acl);
-            entry.fastInsert(KIO::UDSEntry::UDS_ACL_STRING, str);
-            // qDebug() << path.constData() << "ACL:" << str;
-            acl_free(acl);
-        }
-
-        if (defaultAcl) {
-            const QString str = aclToText(defaultAcl);
-            entry.fastInsert(KIO::UDSEntry::UDS_DEFAULT_ACL_STRING, str);
-            // qDebug() << path.constData() << "DEFAULT ACL:" << str;
-            acl_free(defaultAcl);
-        }
-    }
-}
-#endif
-
 // We could port this to KTempDir::removeDir but then we wouldn't be able to tell the user
 // where exactly the deletion failed, in case of errors.
 bool FileProtocol::deleteRecursive(const QString &path)
