@@ -164,6 +164,7 @@ int KFileItemActionsPrivate::insertServicesSubmenus(const QMap<QString, ServiceL
 
         QMenu *actionSubmenu = new QMenu(menu);
         actionSubmenu->setTitle(it.key());
+        actionSubmenu->setIcon(QIcon::fromTheme(it.value().first().icon()));
         actionSubmenu->menuAction()->setObjectName(QStringLiteral("services_submenu")); // for the unittest
         menu->addMenu(actionSubmenu);
         count += insertServices(it.value(), actionSubmenu, isBuiltin);
@@ -177,9 +178,8 @@ int KFileItemActionsPrivate::insertServices(const ServiceList &list,
         bool isBuiltin)
 {
     int count = 0;
-    ServiceList::const_iterator it = list.begin();
-    for (; it != list.end(); ++it) {
-        if ((*it).isSeparator()) {
+    for (const KServiceAction &serviceAction : list) {
+        if (serviceAction.isSeparator()) {
             const QList<QAction *> actions = menu->actions();
             if (!actions.isEmpty() && !actions.last()->isSeparator()) {
                 menu->addSeparator();
@@ -187,16 +187,16 @@ int KFileItemActionsPrivate::insertServices(const ServiceList &list,
             continue;
         }
 
-        if (isBuiltin || !(*it).noDisplay()) {
+        if (isBuiltin || !serviceAction.noDisplay()) {
             QAction *act = new QAction(q);
             act->setObjectName(QStringLiteral("menuaction")); // for the unittest
-            QString text = (*it).text();
+            QString text = serviceAction.text();
             text.replace(QLatin1Char('&'), QLatin1String("&&"));
             act->setText(text);
-            if (!(*it).icon().isEmpty()) {
-                act->setIcon(QIcon::fromTheme((*it).icon()));
+            if (!serviceAction.icon().isEmpty()) {
+                act->setIcon(QIcon::fromTheme(serviceAction.icon()));
             }
-            act->setData(QVariant::fromValue(*it));
+            act->setData(QVariant::fromValue(serviceAction));
             m_executeServiceActionGroup.addAction(act);
 
             menu->addAction(act); // Add to toplevel menu
@@ -245,7 +245,7 @@ void KFileItemActions::setItemListProperties(const KFileItemListProperties &item
 int KFileItemActions::addServiceActionsTo(QMenu *mainMenu)
 {
     const KFileItemList items = d->m_props.items();
-    const KFileItem firstItem = items.first();
+    const KFileItem &firstItem = items.first();
     const QString protocol = firstItem.url().scheme(); // assumed to be the same for all items
     const bool isLocal = !firstItem.localPath().isEmpty();
     const bool isSingleLocal = items.count() == 1 && isLocal;
@@ -487,7 +487,8 @@ int KFileItemActions::addPluginActionsTo(QMenu *mainMenu)
         }
 
         auto mimeType = db.mimeTypeForName(commonMimeType);
-        foreach (const auto& supportedMimeType, metaData.mimeTypes()) {
+        const QStringList list = metaData.mimeTypes();
+        for (const auto &supportedMimeType : list) {
             if (mimeType.inherits(supportedMimeType)) {
                 return true;
             }
@@ -496,7 +497,7 @@ int KFileItemActions::addPluginActionsTo(QMenu *mainMenu)
         return false;
     });
 
-    foreach (const auto& jsonMetadata, jsonPlugins) {
+    for (const auto &jsonMetadata : jsonPlugins) {
         // The plugin has been disabled
         if (!showGroup.readEntry(jsonMetadata.pluginId(), true)) {
             continue;
@@ -607,7 +608,7 @@ void KFileItemActions::addOpenWithActionsTo(QMenu *topMenu, const QString &trade
     //// Ok, we have everything, now insert
 
     const KFileItemList items = d->m_props.items();
-    const KFileItem firstItem = items.first();
+    const KFileItem &firstItem = items.first();
     const bool isLocal = firstItem.url().isLocalFile();
     // "Open With..." for folders is really not very useful, especially for remote folders.
     // (media:/something, or trash:/, or ftp://...)
